@@ -14,7 +14,7 @@ use Crypt::Rijndael::PP::Debug qw( generate_printable_state );
 
 use Crypt::Random::Source qw(get_weak);
 
-our $VERSION = '0.2.1'; # VERSION
+our $VERSION = '0.3.0'; # VERSION
 # ABSTRACT: Pure Perl Implementation of the Rijndael Cipher
 
 use Readonly;
@@ -89,7 +89,11 @@ Readonly my $NUM_ROUNDS => {
 sub new {
     my $class = shift;
     my $key   = shift;
-    my $mode  = shift // MODE_ECB();
+    my $mode  = shift;
+
+    if( !$mode ) {
+        $mode = MODE_ECB();
+    }
 
     my $self = {
         key  => $key,
